# umaat-Ultimate Machiene-learning Algorithm Accuracy Test
  This package consists of various algorithms  which can produce accuracy results for each algorithm in the categories of  Clustering,Regression & Classification based on given the arguments - independent and dependent variables/features
## Development Status:
Under Development (Early release)

### Developed by:

 [Vishal Balaji Sivaraman](https://github.com/TheSocialLion)

### Installation:

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install ML-Accuracy-Calc

```bash
pip install umaat
```

### To import mlaccuracycalc:

```python
import umaat
```
### To use a particular function in mlaccuracycalc:
```python
from umaat import model_accuracy
ma=model_accuracy()
ma.accuracy_test(X,y) 
```

## License:
[MIT](https://choosealicense.com/licenses/mit/)
